﻿/*
  TCATO_Placeholder Plugin
  Copyright (C) 2015 Nikolaus Hammler <niki@hammler.net>
 
  Thanks to Alex Vallat's AutoTypeShow plugin from which I could literally
  copy this plugin within one hour.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

using System;
using System.Windows.Forms;
using System.Drawing;
using System.Text.RegularExpressions;

using KeePass.Plugins;
using KeePass.Util;
using KeePass.Util.Spr;

namespace TCATO_Placeholder
{
    public sealed class TCATO_PlaceholderExt : Plugin
    {
        private const string UPDATEURL = "https://secure.nobaq.net/keepass-updates.txt";

        private const string m_strPlaceholderTrue = "{TCATO:true}";
        private const string m_strPlaceholderFalse = "{TCATO:false}";

        private IPluginHost m_host = null;

        public override bool Initialize(IPluginHost host)
        {
            m_host = host;
            AutoType.FilterCompilePre += this.OnAutoTypeFilterCompilePre;
            SprEngine.FilterPlaceholderHints.Add(m_strPlaceholderTrue);
            SprEngine.FilterPlaceholderHints.Add(m_strPlaceholderFalse);
            return true;
        }

        public override void Terminate()
        {
            SprEngine.FilterPlaceholderHints.Remove(m_strPlaceholderTrue);
            SprEngine.FilterPlaceholderHints.Remove(m_strPlaceholderFalse);
            AutoType.FilterCompilePre -= this.OnAutoTypeFilterCompilePre;
        }

        public override string UpdateUrl
        {
            get { return UPDATEURL; }
        }

        public override Image SmallIcon
        {
            //get { return Resources.KeeAgentIcon_png; }
            get { return Resources.b16x16_ktouch; }
        }

        private void OnAutoTypeFilterCompilePre(object sender, AutoTypeEventArgs autoTypeEventArgs)
        {
            Regex replacerTrue = new Regex(Regex.Escape(m_strPlaceholderTrue), RegexOptions.IgnoreCase);
            Regex replacerFalse = new Regex(Regex.Escape(m_strPlaceholderFalse), RegexOptions.IgnoreCase);

            autoTypeEventArgs.Sequence = replacerTrue.Replace(autoTypeEventArgs.Sequence, match =>
                {
                    autoTypeEventArgs.SendObfuscated = true;
                    return String.Empty;
                });

            autoTypeEventArgs.Sequence = replacerFalse.Replace(autoTypeEventArgs.Sequence, match =>
            {
                autoTypeEventArgs.SendObfuscated = false;
                return String.Empty;
            });
        }
    }
}
